@@ -3,12 +3,17 @@ package PDF::Builder::Resource::Colors;
 use strict;
 use warnings;
 
-our $VERSION = '3.019'; # VERSION
-my $LAST_UPDATE = '2.029'; # manually update whenever code is changed
+our $VERSION = '3.027'; # VERSION
+our $LAST_UPDATE = '3.027'; # manually update whenever code is changed
 
 =head1 NAME
 
-PDF::Builder::Resource::Colors - translate color names into RGB settings
+PDF::Builder::Resource::Colors - Translate color names into RGB settings
+
+=head1 SYNOPSIS
+
+This list is an amalgamation of the X11, SGML, and (X)HTML 
+color specification sets.
 
 =cut
 
