@@ -3,12 +3,12 @@ package PDF::Builder::Resource::Font::CoreFont::symbol;
 use strict;
 use warnings;
 
-our $VERSION = '3.019'; # VERSION
-my $LAST_UPDATE = '3.019'; # manually update whenever code is changed
+our $VERSION = '3.027'; # VERSION
+our $LAST_UPDATE = '3.027'; # manually update whenever code is changed
 
 =head1 NAME
 
-PDF::Builder::Resource::Font::CoreFont::symbol - font-specific information for the Symbol font
+PDF::Builder::Resource::Font::CoreFont::symbol - Font-specific information for the Symbol font
 
 =cut
 
